"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.detectInvokedPackageManager = exports.getPackageManagerVersion = exports.getPackageManagerCommand = exports.detectPackageManager = exports.packageManagerList = void 0;
const child_process_1 = require("child_process");
const fs_1 = require("fs");
const path_1 = require("path");
/*
 * Because we don't want to depend on @nrwl/workspace (to speed up the workspace creation)
 * we duplicate the helper functions from @nrwl/workspace in this file.
 */
exports.packageManagerList = ['pnpm', 'yarn', 'npm'];
function detectPackageManager(dir = '') {
    return (0, fs_1.existsSync)((0, path_1.join)(dir, 'yarn.lock'))
        ? 'yarn'
        : (0, fs_1.existsSync)((0, path_1.join)(dir, 'pnpm-lock.yaml'))
            ? 'pnpm'
            : 'npm';
}
exports.detectPackageManager = detectPackageManager;
/**
 * Returns commands for the package manager used in the workspace.
 * By default, the package manager is derived based on the lock file,
 * but it can also be passed in explicitly.
 *
 * Example:
 *
 * ```javascript
 * execSync(`${getPackageManagerCommand().addDev} my-dev-package`);
 * ```
 *
 */
function getPackageManagerCommand(packageManager = detectPackageManager()) {
    var _a;
    switch (packageManager) {
        case 'yarn':
            return {
                install: 'yarn',
                exec: 'yarn',
            };
        case 'pnpm':
            const [major, minor] = getPackageManagerVersion('pnpm').split('.');
            let useExec = false;
            if ((+major >= 6 && +minor >= 13) || +major >= 7) {
                useExec = true;
            }
            return {
                install: 'pnpm install --no-frozen-lockfile',
                exec: useExec ? 'pnpm exec' : 'pnpx',
            };
        case 'npm':
            process.env.npm_config_legacy_peer_deps =
                (_a = process.env.npm_config_legacy_peer_deps) !== null && _a !== void 0 ? _a : 'true';
            return {
                install: 'npm install',
                exec: 'npx',
            };
    }
}
exports.getPackageManagerCommand = getPackageManagerCommand;
function getPackageManagerVersion(packageManager) {
    return (0, child_process_1.execSync)(`${packageManager} --version`).toString('utf-8').trim();
}
exports.getPackageManagerVersion = getPackageManagerVersion;
/**
 * Detects which package manager was used to invoke create-nx-{plugin|workspace} command
 * based on the main Module process that invokes the command
 * - npx returns 'npm'
 * - pnpx returns 'pnpm'
 * - yarn create returns 'yarn'
 *
 * Default to 'npm'
 */
function detectInvokedPackageManager() {
    let detectedPackageManager = 'npm';
    // mainModule is deprecated since Node 14, fallback for older versions
    const invoker = require.main || process['mainModule'];
    // default to `npm`
    if (!invoker) {
        return detectedPackageManager;
    }
    for (const pkgManager of exports.packageManagerList) {
        if (invoker.path.includes(pkgManager)) {
            detectedPackageManager = pkgManager;
            break;
        }
    }
    return detectedPackageManager;
}
exports.detectInvokedPackageManager = detectInvokedPackageManager;
//# sourceMappingURL=package-manager.js.map